from setuptools import setup, find_packages
setup(
    name="7xydothis",
    version="0.1",
    packages=find_packages(),
    description = "Utitilies to use the APIs",
    long_description = "Utitilies to use the APIs",
    author = "bernardfrk",
    author_email = "bernard.frk@gmail.com",
    maintainer='bernardfrk',
    maintainer_email='bernard.frk@gmail.com',    
    url='https://github.com/frkb/7xydothis',
    classifiers = [],
    
)